**Example 1: 移动成员到指定企业组织节点**



Input: 

```
tccli organization MoveOrganizationNodeMembers --cli-unfold-argument  \
    --MemberUin 100000023837 \
    --NodeId 123
```

Output: 
```
{
    "Response": {
        "RequestId": "b46d2afe-6893-4529-bc96-2c82d9214957"
    }
}
```

